Plugin: JS9Toolbar

### JS9 Toolbar

The JS9 Toolbar plugin displays tool icons that can be clicked to execute shortcut functions such as creating a region, zooming in and out of the image, or changing the scaling algorithm. Hover the mouse over an icon to identify the action that will be performed (non-mobile devices only).

The display of tools supplied by JS9 is separated into two lists: the top-level list consists of the tools that are specified in the JS9.globalOpts.toolBar array. Other tools are displayed in a lower list, accessible by scrolling down. In this way, your favorite tools can be placed at the top-level, but all tools remain available. See Configuring JS9 Site Preferences and the JS9 User Preferences plugin for discussions of how to set preferences such as JS9.globalOpts.toolBar on a site-wide and an individual basis, respectively.

New tools can be added to the toolbar at any time using the JS9.SetToolbar() public access routine. The text properties associated with a tool object are:

- name: name of the tool
- tip: a tooltip to display when the mouse hovers over the tool
- image: url (relative to the install directory) containing a PNG image file to display as the tool icon
- cmd: name of the JS9 public routine to execute when the tool is clicked
- args: array of arguments to pass to the JS9 public routine

Only the name and cmd properties are required. If no image is specified, a button labeled by the name value will be used.

Examples of tool objects:

      {
        "name": "linear",
        "tip": "linear scale",
        "image": "images/toolbar/dax_images/lin.png",
        "cmd": "SetScale",
        "args": ["linear"]
      },
      {
        "name": "histeq",
        "tip": "histogram equalization",
        "cmd": "SetScale",
        "args": ["histeq"]
      },
      {
        "name": "annulus",
        "tip": "annulus region",
        "image": "images/toolbar/dax_images/annulus.png",
        "cmd": "AddRegions",
        "args": ["annulus"]
      },
      {
        "name": "remove",
        "tip": "remove selected region",
        "image": "images/toolbar/dax_images/erase.png",
        "cmd": "RemoveRegions",
        "args": ["selected"]
      },
      {
        "name": "zoom1",
        "tip": "zoom 1",
        "image": "images/toolbar/dax_images/mag_one.png",
        "cmd": "SetZoom",
        "args": [1]
      },
      {
        "name": "magnifier",
        "tip": "toggle magnifier display",
        "image": "images/toolbar/dax_images/mag.png",
        "cmd": "DisplayPlugin",
        "args": ["JS9Magnifier"]
      }

See the The JS9 Public API for more information about this routine.